@@ -1,5 +1,5 @@
 
 tam_mml_3pl_vec_add_increment <- function( vec, h , index ){
 	vec[index] <- vec[index] + h
-	base::return(vec)
-}	
\ No newline at end of file
+	return(vec)
+}	
